#!/bin/bash

[ $# == 2 ] || { echo "Usage: $0 genome_fasta accepted_hits.sam." >&2; exit 1; }

CMDS=( samtools samtools.pl )
for c in ${CMDS[@]}; do
  type -P $c &> /dev/null || { echo "Error: can't find $c. Make sure it's in your PATH." >&2; exit 1; }
done

[ -e $1 ] || { echo "Error: can't find genome FASTA $1. Usage: $0 genome_fasta accepted_hits.sam." >&2; exit 1; }
[ -e $2 ] || { echo "Error: can't find SAM file $2. Usage: $0 genome_fasta accepted_hits.sam." >&2; exit 1; }

if [ ! -e  "$1.fai" ]; then
  echo -n "$1.fai does not exist. Creating it..."
  samtools faidx $1
  echo "done."
fi

DIRN=`dirname $2`
BASEN=`basename $2 .sam`

samtools import $1.fai $2 ${DIRN}/${BASEN}.bam
samtools sort ${DIRN}/${BASEN}.bam ${DIRN}/${BASEN}.sorted
samtools pileup -cf $1 ${DIRN}/${BASEN}.sorted.bam > ${DIRN}/raw.pileup
samtools.pl varFilter -D 10000 ${DIRN}/raw.pileup | awk '$6>=20' > ${DIRN}/final.pileup
